@@ -3,27 +3,6 @@ from nettoolkit import *
 
 # ------------------------------------------------------------------------------
 
-def get_subnet(address):
-	"""get subnet zero network address for provided v4 address
-
-	Args:
-		address (str): ipv4 address
-
-	Returns:
-		str: subnet zero/network address
-	"""	
-	return IPv4(address).subnet_zero()
-
-def get_v6_subnet(address):
-	"""get subnet zero network address for provided v6 address
-
-	Args:
-		address (str): ipv6 address
-
-	Returns:
-		str: subnet zero/network address
-	"""	
-	return IPv6(address).subnet_zero()
 
 def get_vlans_juniper(spl, how="s"):
 	"""get the list of vlans on the interface
